# insider-scraper
A simple CLI app for scraping events from insider.in
# Installation
## Using Pip
```bash
  $ pip install insider-scraper
```
## Manual
```bash
  $ git clone https://github.com/MinatoNamikaze02/insider-scraper
  $ cd insider-scraper
  $ python setup.py install
```
# Usage
```bash
$ cver
```
## Search
`search <keyword>`
```bash
$ cver search python
```
## Lookup
`search <name>`
```bash
$ cver look-up CVE-2020-2121
```